@@ -1,7 +1,7 @@
 #include <kdialog.h>
 #include <klocale.h>
 
-#include "/usr/src/ports/kfilereplace/kfilereplace-17.04.3-1.x86_64/build/kfilereplaceviewwdg.h"
+#include "/usr/src/ports/kfilereplace/kfilereplace-17.08.3-1.i686/build/kfilereplaceviewwdg.h"
 
 #include <qvariant.h>
 /*
